@@ -198,13 +198,13 @@ class Insight_Definition:
                 for col in cols:
                     columns.append(col)
 
-        print(columns)
         settings = {}
         for field in field_codes.keys():
-            ids = []
             if(field_codes[field]["multiple"]):
+                ids = []
                 for column in columns:
                     if(column["code"] in field_codes[field]["value"] or column["name"] in field_codes[field]["value"]):
+                        print(column["code"])
                         for query in query_ids:
                             if(str(field_codes[field]["value"]).startswith(query)):
                                if(str(column["id"]).startswith(query)):
@@ -213,28 +213,25 @@ class Insight_Definition:
                                    continue
                             else:
                                 ids.append(column["id"])
-
                 settings[field + "_id"] = ids
 
             else:
-                for field in field_codes.keys():
-                    for column in columns:
-                        if (column["code"] in field_codes[field]["value"] or column["name"] in field_codes[field]["value"]):
-                            for query in query_ids:
-                                if (str(field_codes[field]["value"]).startswith(query)):
-                                    if (str(column["id"]).startswith(query)):
-                                        settings[field + "_id"] = column["id"]
-                                        break
-                                    else:
-                                        continue
-                                else:
+                for column in columns:
+                    if (column["code"] in field_codes[field]["value"] or column["name"] in field_codes[field]["value"]):
+                        for query in query_ids:
+                            if (str(field_codes[field]["value"]).startswith(query)):
+                                if (str(column["id"]).startswith(query)):
                                     settings[field + "_id"] = column["id"]
                                     break
+                                else:
+                                    continue
+                            else:
+                                settings[field + "_id"] = column["id"]
+                                break
 
         for key in values.keys():
             settings[key + "_id"] = values[key]
 
-        print(settings)
         body = {
             "id" : widget_id,
             "type": "widget",
